@@ -14,13 +14,13 @@ use Getopt::Long qw(:config no_auto_abbrev no_ignore_case);
 use Perl::Strip;
 use Pod::Usage 'pod2usage';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our $IGNORE_FILE = [
     qr/\.pod$/,
-    qr/^\.packlist$/,
-    qr/^MYMETA\.json$/,
-    qr/^install\.json$/,
+    qr/\.packlist$/,
+    qr/MYMETA\.json$/,
+    qr/install\.json$/,
 ];
 
 sub new {
@@ -40,8 +40,9 @@ sub parse_options {
         "s|strict"      => \(my $strict),
         "v|version"     => sub { printf "%s %s\n", __PACKAGE__, __PACKAGE__->VERSION; exit },
         "color!"        => \(my $color = 1),
-        "no-perl-strip" => \(my $no_perl_strip),
         "shebang=s"     => \(my $custom_shebang),
+        "exclude-strip=s@" => \(my $exclude_strip),
+        "no-strip|no-perl-strip" => \(my $no_perl_strip),
     or pod2usage(1);
     $self->{script}     = shift @ARGV or do { warn "Missing scirpt.\n"; pod2usage(1) };
     $self->{dir}        = $self->build_dir($dir);
@@ -51,6 +52,7 @@ sub parse_options {
     $self->{color}      = $color;
     $self->{perl_strip} = $no_perl_strip ? undef : Perl::Strip->new;
     $self->{custom_shebang} = $custom_shebang;
+    $self->{exclude_strip}  = [map { qr/$_/ } @{$exclude_strip || []}];
     $self->{exclude}    = [];
     if ($exclude) {
         for my $e (split /,/, $exclude) {
@@ -143,39 +145,43 @@ sub load_main_script {
 }
 
 sub load_file {
-    my ($self, $file, $dir) = @_;
+    my ($self, $absolute, $relative, $original) = @_;
 
     my $content = do {
-        open my $fh, "<", $file or die "Cannot open '$file': $!\n";
+        open my $fh, "<", $absolute or die "Cannot open '$absolute': $!\n";
         local $/; <$fh>;
     };
-    my $relative = File::Spec::Unix->abs2rel($file, $dir);
-    my $message  = $self->{perl_strip} ? "perl-strip" : "fatpack";
-    $self->debug("$message $relative");
-    $self->{perl_strip} ? $self->{perl_strip}->strip($content) : $content;
+
+    if ($self->{perl_strip} and !grep { $original =~ $_ } @{$self->{exclude_strip}}) {
+        $self->debug("fatpack $relative (with perl-strip)");
+        return $self->{perl_strip}->strip($content);
+    } else {
+        $self->debug("fatpack $relative (without perl-strip)");
+        return $content;
+    }
 }
 
 sub collect_files {
     my ($self, $dir, $files) = @_;
 
+    my $absolute_dir = abs_path($dir);
     # When $dir is not an archlib,
     # and we are about to search $dir/archlib, skip it!
     # because $dir/archlib itself will be searched another time.
-    my $skip_dir = catdir($dir, $Config{archname});
+    my $skip_dir = catdir($absolute_dir, $Config{archname});
     $skip_dir = qr/\Q$skip_dir\E/;
 
-    find sub {
+    my $find = sub {
         return unless -f $_;
         for my $ignore (@$IGNORE_FILE) {
             $_ =~ $ignore and return;
         }
-        if ($File::Find::name =~ $skip_dir) {
-            return;
-        }
-
-        my $relative = File::Spec::Unix->abs2rel($File::Find::name, $dir);
+        my $original = $_;
+        my $absolute = abs_path($original);
+        return if $absolute =~ $skip_dir;
+        my $relative = File::Spec::Unix->abs2rel($absolute, $absolute_dir);
         for my $exclude (@{$self->{exclude}}) {
-            if ($File::Find::name eq $exclude) {
+            if ($absolute eq $exclude) {
                 $self->debug("exclude $relative");
                 return;
             }
@@ -184,14 +190,15 @@ sub collect_files {
             $self->warning("skip non perl module file $relative");
             return;
         }
-        $files->{$relative} = $self->load_file($File::Find::name, $dir);
-    }, $dir;
+        $files->{$relative} = $self->load_file($absolute, $relative, $original);
+    };
+    find({wanted => $find, no_chdir => 1}, $dir);
 }
 
 sub build_dir {
     my ($self, $dir_string) = @_;
     my @dir;
-    for my $d (map { abs_path $_ } grep -d, split /,/, $dir_string) {
+    for my $d (grep -d, split /,/, $dir_string) {
         my $try = catdir($d, "lib/perl5");
         if (-d $try) {
             push @dir, $try, catdir($try, $Config{archname});
